@@ -142,9 +142,17 @@ class InpatientRegistration(ModelSQL, ModelView):
 
     discharged_by = fields.Many2One(
         'gnuhealth.healthprofessional', 'Discharged by', readonly=True,
-        states={'invisible': Equal(Eval('state'), 'in_progress')},
+        states={'invisible': Not(Equal(Eval('state'), 'done'))},
         help="Health Professional that discharged the patient")
 
+    institution = fields.Many2One('gnuhealth.institution', 'Institution')
+
+    @staticmethod
+    def default_institution():
+        HealthInst = Pool().get('gnuhealth.institution')
+        institution = HealthInst.get_institution()
+        return institution
+
     @classmethod
     def __setup__(cls):
         super(InpatientRegistration, cls).__setup__()
@@ -206,7 +214,14 @@ class InpatientRegistration(ModelSQL, ModelView):
         registration_id = registrations[0]
         Bed = Pool().get('gnuhealth.hospital.bed')
 
-        cls.write(registrations, {'state': 'done'})
+        signing_hp = Pool().get('gnuhealth.healthprofessional').get_health_professional()
+        if not signing_hp:
+            cls.raise_user_error(
+                "No health professional associated to this user !")
+
+        cls.write(registrations, {'state': 'done',
+            'discharged_by': signing_hp})
+
         Bed.write([registration_id.bed], {'state': 'free'})
 
     @classmethod
@@ -378,12 +393,9 @@ class InpatientMedication (ModelSQL, ModelView):
     frequency_prn = fields.Boolean('PRN',
         help='Use it as needed, pro re nata')
     is_active = fields.Boolean('Active',
-        on_change_with=['discontinued', 'course_completed'],
         help='Check if the patient is currently taking the medication')
-    discontinued = fields.Boolean('Discontinued',
-        on_change_with=['is_active', 'course_completed'])
-    course_completed = fields.Boolean('Course Completed',
-        on_change_with=['is_active', 'discontinued'])
+    discontinued = fields.Boolean('Discontinued')
+    course_completed = fields.Boolean('Course Completed')
     discontinued_reason = fields.Char('Reason for discontinuation',
         states={
             'invisible': Not(Bool(Eval('discontinued'))),
@@ -394,15 +406,18 @@ class InpatientMedication (ModelSQL, ModelView):
     adverse_reaction = fields.Text('Adverse Reactions',
         help='Side effects or adverse reactions that the patient experienced')
 
+    @fields.depends('discontinued', 'course_completed')
     def on_change_with_is_active(self):
         is_active = True
         if (self.discontinued or self.course_completed):
             is_active = False
         return is_active
 
+    @fields.depends('is_active', 'course_completed')
     def on_change_with_discontinued(self):
         return not (self.is_active or self.course_completed)
 
+    @fields.depends('is_active', 'discontinued')
     def on_change_with_course_completed(self):
         return not (self.is_active or self.discontinued)
 
