@@ -32,7 +32,10 @@ class DrugsRecreational(ModelSQL, ModelView):
     'Recreational Drug'
     __name__ = 'gnuhealth.drugs_recreational'
 
-    name = fields.Char('Name', translate=True, help="Name of the drug")
+    name = fields.Char('Name', translate=True, required=True,
+        help="Name of the drug")
+    code = fields.Char('Code', required=True,
+        help="Please use CAPITAL LETTERS and no spaces")
     street_name = fields.Char('Street names',
         help="Common name of the drug in street jargon")
 
@@ -167,6 +170,17 @@ class DrugsRecreational(ModelSQL, ModelView):
 
     info = fields.Text('Extra Info')
 
+    @classmethod
+    def __setup__(cls):
+        super(DrugsRecreational, cls).__setup__()
+        cls._sql_constraints = [
+            ('NAME_uniq', 'UNIQUE(name)',
+                'The Recreational Drug NAME must be unique'),
+            ('code_uniq', 'UNIQUE(code)',
+                'The Recreational Drug CODE must be unique'),
+
+        ]
+
 
 class PatientRecreationalDrugs(ModelSQL, ModelView):
     'Patient use of Recreational Drugs'
@@ -197,9 +211,9 @@ class PatientCAGE(ModelSQL, ModelView):
         'needed a drink first thing in the morning (Eye-opener) to steady '
         'your nerves or to get rid of a hangover?')
 
-    cage_score = fields.Integer('CAGE Score',
-        on_change_with=['cage_c', 'cage_a', 'cage_g', 'cage_e'])
+    cage_score = fields.Integer('CAGE Score')
 
+    @fields.depends('cage_c', 'cage_a', 'cage_g', 'cage_e')
     def on_change_with_cage_score(self):
         total = 0
 
