@@ -196,7 +196,7 @@ class PatientAmbulatoryCare(Workflow, ModelSQL, ModelView):
             vaccinations = []
             for vaccine in ambulatory.vaccines:
                 lot_number = ''
-                expiration_date = ''
+                expiration_date = None
                 if vaccine.lot:
                     if vaccine.lot.number:
                         lot_number = vaccine.lot.number
@@ -299,7 +299,7 @@ class PatientAmbulatoryCareMedicament(ModelSQL, ModelView):
     name = fields.Many2One('gnuhealth.patient.ambulatory_care',
         'Ambulatory ID')
     medicament = fields.Many2One('gnuhealth.medicament', 'Medicament',
-        required=True, on_change=['medicament', 'product'])
+        required=True)
     product = fields.Many2One('product.product', 'Product')
     quantity = fields.Integer('Quantity')
     short_comment = fields.Char('Comment',
@@ -311,6 +311,7 @@ class PatientAmbulatoryCareMedicament(ModelSQL, ModelView):
     def default_quantity():
         return 1
 
+    @fields.depends('medicament', 'product')
     def on_change_medicament(self):
         res = {}
         if self.medicament:
@@ -447,7 +448,7 @@ class PatientRounding(Workflow, ModelSQL, ModelView):
 
             for vaccine in rounding.vaccines:
                 lot_number = ''
-                expiration_date = ''
+                expiration_date = None
                 if vaccine.lot:
                     if vaccine.lot.number:
                         lot_number = vaccine.lot.number
@@ -547,7 +548,7 @@ class PatientRoundingMedicament(ModelSQL, ModelView):
 
     name = fields.Many2One('gnuhealth.patient.rounding', 'Ambulatory ID')
     medicament = fields.Many2One('gnuhealth.medicament', 'Medicament',
-        required=True, on_change=['medicament', 'product'])
+        required=True)
     product = fields.Many2One('product.product', 'Product')
     quantity = fields.Integer('Quantity')
     short_comment = fields.Char('Comment',
@@ -559,6 +560,7 @@ class PatientRoundingMedicament(ModelSQL, ModelView):
     def default_quantity():
         return 1
 
+    @fields.depends('medicament', 'product')
     def on_change_medicament(self):
         res = {}
         if self.medicament:
